@@ -61,6 +61,7 @@ static DefaultCursor default_cursors[] = {
   { "text", IDC_IBEAM },
   { "move", IDC_SIZEALL },
   { "not-allowed", IDC_NO },
+  { "all-scroll", IDC_SIZEALL },
   { "ew-resize", IDC_SIZEWE },
   { "e-resize", IDC_SIZEWE },
   { "w-resize", IDC_SIZEWE },
@@ -230,22 +231,16 @@ gdk_win32_hcursor_class_init (GdkWin32HCursorClass *klass)
   object_class->set_property = gdk_win32_hcursor_set_property;
 
   hcursor_props[PROP_DISPLAY] =
-      g_param_spec_object ("display",
-                           P_("Display"),
-                           P_("The display that will use this cursor"),
+      g_param_spec_object ("display", NULL, NULL,
                            GDK_TYPE_DISPLAY,
                            G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE);
 
   hcursor_props[PROP_HANDLE] =
-      g_param_spec_pointer ("handle",
-                            P_("Handle"),
-                            P_("The HCURSOR handle for this cursor"),
+      g_param_spec_pointer ("handle", NULL, NULL,
                             G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE);
 
   hcursor_props[PROP_DESTROYABLE] =
-      g_param_spec_boolean ("destroyable",
-                            P_("Destroyable"),
-                            P_("Whether calling DestroyCursor() is allowed on this cursor"),
+      g_param_spec_boolean ("destroyable", NULL, NULL,
                             TRUE,
                             G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE);
 
@@ -1492,17 +1487,17 @@ _gdk_win32_pixbuf_to_hcursor (GdkPixbuf *pixbuf,
 
 /**
  * gdk_win32_display_get_win32hcursor:
- * @display: (type GdkWin32Display): a #GdkDisplay
- * @cursor: a #GdkCursor.
- * 
- * Returns the Win32 HCURSOR wrapper object belonging to a #GdkCursor,
+ * @display: (type GdkWin32Display): a `GdkDisplay`
+ * @cursor: a `GdkCursor`
+ *
+ * Returns the Win32 HCURSOR wrapper object belonging to a `GdkCursor`,
  * potentially creating the cursor object.
  *
  * Be aware that the returned cursor may not be unique to @cursor.
  * It may for example be shared with its fallback cursor.
- * 
- * Returns: a GdkWin32HCursor.
- **/
+ *
+ * Returns: a GdkWin32HCursor
+ */
 GdkWin32HCursor *
 gdk_win32_display_get_win32hcursor (GdkWin32Display *display,
                                     GdkCursor       *cursor)
