@@ -32,8 +32,9 @@
 #include "gdk/gdkcursor.h"
 
 #include <windows.h>
+#include <directmanipulation.h>
 
-#ifdef GDK_WIN32_ENABLE_EGL
+#ifdef HAVE_EGL
 # include <epoxy/egl.h>
 #endif
 
@@ -337,10 +338,12 @@ struct _GdkWin32Surface
     int configured_height;
     RECT configured_rect;
   } next_layout;
+  gboolean force_recompute_size;
 
-#ifdef GDK_WIN32_ENABLE_EGL
-  EGLSurface egl_surface;
-  EGLSurface egl_dummy_surface;
+  IDirectManipulationViewport *dmanipulation_viewport_pan;
+  IDirectManipulationViewport *dmanipulation_viewport_zoom;
+
+#ifdef HAVE_EGL
   guint egl_force_redraw_all : 1;
 #endif
 };
@@ -373,7 +376,7 @@ void gdk_win32_surface_move_resize (GdkSurface *window,
 RECT
 gdk_win32_surface_handle_queued_move_resize (GdkDrawContext *draw_context);
 
-#ifdef GDK_WIN32_ENABLE_EGL
+#ifdef HAVE_EGL
 EGLSurface gdk_win32_surface_get_egl_surface (GdkSurface *surface,
                                               EGLConfig   config,
                                               gboolean    is_dummy);
