@@ -47,9 +47,32 @@
  * the full width of the box, even if the children at either side take
  * up different amounts of space.
  *
+ * # GtkActionBar as GtkBuildable
+ *
+ * The `GtkActionBar` implementation of the `GtkBuildable` interface supports
+ * adding children at the start or end sides by specifying “start” or “end” as
+ * the “type” attribute of a `<child>` element, or setting the center widget
+ * by specifying “center” value.
+ *
  * # CSS nodes
  *
- * `GtkActionBar` has a single CSS node with name actionbar.
+ * ```
+ * actionbar
+ * ╰── revealer
+ *     ╰── box
+ *         ├── box.start
+ *         │   ╰── [start children]
+ *         ├── [center widget]
+ *         ╰── box.end
+ *             ╰── [end children]
+ * ```
+ *
+ * A `GtkActionBar`'s CSS node is called `actionbar`. It contains a `revealer`
+ * subnode, which contains a `box` subnode, which contains two `box` subnodes at
+ * the start and end of the action bar, with `start` and `end style classes
+ * respectively, as well as a center node that represents the center child.
+ *
+ * Each of the boxes contains children packed for that side.
  */
 
 typedef struct _GtkActionBarClass         GtkActionBarClass;
@@ -155,9 +178,7 @@ gtk_action_bar_class_init (GtkActionBarClass *klass)
    * Controls whether the action bar shows its contents.
    */
   props[PROP_REVEALED] =
-    g_param_spec_boolean ("revealed",
-                          P_("Reveal"),
-                          P_("Controls whether the action bar shows its contents or not"),
+    g_param_spec_boolean ("revealed", NULL, NULL,
                           TRUE,
                           GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
 
@@ -181,6 +202,9 @@ gtk_action_bar_init (GtkActionBar *self)
   self->start_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   self->end_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
+  gtk_widget_add_css_class (self->start_box, "start");
+  gtk_widget_add_css_class (self->end_box, "end");
+
   self->center_box = gtk_center_box_new ();
   gtk_center_box_set_start_widget (GTK_CENTER_BOX (self->center_box), self->start_box);
   gtk_center_box_set_end_widget (GTK_CENTER_BOX (self->center_box), self->end_box);
@@ -272,7 +296,7 @@ gtk_action_bar_remove (GtkActionBar *action_bar,
 /**
  * gtk_action_bar_set_center_widget:
  * @action_bar: a `GtkActionBar`
- * @center_widget: (allow-none): a widget to use for the center
+ * @center_widget: (nullable): a widget to use for the center
  *
  * Sets the center widget for the `GtkActionBar`.
  */
@@ -289,7 +313,7 @@ gtk_action_bar_set_center_widget (GtkActionBar *action_bar,
  *
  * Retrieves the center bar widget of the bar.
  *
- * Returns: (transfer none) (nullable): the center `GtkWidget` or %NULL.
+ * Returns: (transfer none) (nullable): the center `GtkWidget`
  */
 GtkWidget *
 gtk_action_bar_get_center_widget (GtkActionBar *action_bar)
@@ -343,7 +367,7 @@ gtk_action_bar_set_revealed (GtkActionBar *action_bar,
  * Gets whether the contents of the action bar are revealed.
  *
  * Returns: the current value of the [property@Gtk.ActionBar:revealed]
- * property.
+ *   property
  */
 gboolean
 gtk_action_bar_get_revealed (GtkActionBar *action_bar)
