@@ -85,22 +85,24 @@ static GParamSpec *properties[N_PROPS] = { NULL, };
 
 static void
 gtk_builder_list_item_factory_setup (GtkListItemFactory *factory,
-                                     GtkListItemWidget  *widget,
-                                     GtkListItem        *list_item)
+                                     GObject            *item,
+                                     gboolean            bind,
+                                     GFunc               func,
+                                     gpointer            data)
 {
   GtkBuilderListItemFactory *self = GTK_BUILDER_LIST_ITEM_FACTORY (factory);
   GtkBuilder *builder;
   GError *error = NULL;
 
-  GTK_LIST_ITEM_FACTORY_CLASS (gtk_builder_list_item_factory_parent_class)->setup (factory, widget, list_item);
+  GTK_LIST_ITEM_FACTORY_CLASS (gtk_builder_list_item_factory_parent_class)->setup (factory, item, bind, func, data);
 
   builder = gtk_builder_new ();
 
-  gtk_builder_set_current_object (builder, G_OBJECT (list_item));
+  gtk_builder_set_current_object (builder, item);
   if (self->scope)
     gtk_builder_set_scope (builder, self->scope);
 
-  if (!gtk_builder_extend_with_template (builder, G_OBJECT (list_item), G_OBJECT_TYPE (list_item),
+  if (!gtk_builder_extend_with_template (builder, G_OBJECT (item), G_OBJECT_TYPE (item),
                                          (const char *)g_bytes_get_data (self->data, NULL),
                                          g_bytes_get_size (self->data),
                                          &error))
@@ -264,9 +266,7 @@ gtk_builder_list_item_factory_class_init (GtkBuilderListItemFactoryClass *klass)
    * `GBytes` containing the UI definition.
    */
   properties[PROP_BYTES] =
-    g_param_spec_boxed ("bytes",
-                        P_("Bytes"),
-                        P_("bytes containing the UI definition"),
+    g_param_spec_boxed ("bytes", NULL, NULL,
                         G_TYPE_BYTES,
                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
@@ -276,9 +276,7 @@ gtk_builder_list_item_factory_class_init (GtkBuilderListItemFactoryClass *klass)
    * Path of the resource containing the UI definition.
    */
   properties[PROP_RESOURCE] =
-    g_param_spec_string ("resource",
-                         P_("Resource"),
-                         P_("resource containing the UI definition"),
+    g_param_spec_string ("resource", NULL, NULL,
                          NULL,
                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
@@ -288,9 +286,7 @@ gtk_builder_list_item_factory_class_init (GtkBuilderListItemFactoryClass *klass)
    * `GtkBuilderScope` to use when instantiating listitems
    */
   properties[PROP_SCOPE] =
-    g_param_spec_object ("scope",
-                         P_("Scope"),
-                         P_("scope to use when instantiating listitems"),
+    g_param_spec_object ("scope", NULL, NULL,
                          GTK_TYPE_BUILDER_SCOPE,
                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
