@@ -24,15 +24,15 @@
  *
  * Stores geometrical information for a series of rows in a GtkCellArea
  *
- * The #GtkCellAreaContext object is created by a given #GtkCellArea
- * implementation via its #GtkCellAreaClass.create_context() virtual
+ * The `GtkCellAreaContext` object is created by a given `GtkCellArea`
+ * implementation via its `GtkCellAreaClass.create_context()` virtual
  * method and is used to store cell sizes and alignments for a series of
- * #GtkTreeModel rows that are requested and rendered in the same context.
+ * `GtkTreeModel` rows that are requested and rendered in the same context.
  *
- * #GtkCellLayout widgets can create any number of contexts in which to
+ * `GtkCellLayout` widgets can create any number of contexts in which to
  * request and render groups of data rows. However, it’s important that the
- * same context which was used to request sizes for a given #GtkTreeModel
- * row also be used for the same row when calling other #GtkCellArea APIs
+ * same context which was used to request sizes for a given `GtkTreeModel`
+ * row also be used for the same row when calling other `GtkCellArea` APIs
  * such as gtk_cell_area_render() and gtk_cell_area_event().
  */
 
@@ -105,73 +105,63 @@ gtk_cell_area_context_class_init (GtkCellAreaContextClass *class)
   /**
    * GtkCellAreaContext:area:
    *
-   * The #GtkCellArea this context was created by
+   * The `GtkCellArea` this context was created by
    */
   g_object_class_install_property (object_class,
                                    PROP_CELL_AREA,
-                                   g_param_spec_object ("area",
-                                                        P_("Area"),
-                                                        P_("The Cell Area this context was created for"),
+                                   g_param_spec_object ("area", NULL, NULL,
                                                         GTK_TYPE_CELL_AREA,
                                                         GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
   /**
    * GtkCellAreaContext:minimum-width:
    *
-   * The minimum width for the #GtkCellArea in this context
-   * for all #GtkTreeModel rows that this context was requested
+   * The minimum width for the `GtkCellArea` in this context
+   * for all `GtkTreeModel` rows that this context was requested
    * for using gtk_cell_area_get_preferred_width().
    */
   g_object_class_install_property (object_class,
                                    PROP_MIN_WIDTH,
-                                   g_param_spec_int ("minimum-width",
-                                                     P_("Minimum Width"),
-                                                     P_("Minimum cached width"),
+                                   g_param_spec_int ("minimum-width", NULL, NULL,
                                                      -1, G_MAXINT, -1,
                                                      GTK_PARAM_READABLE));
 
   /**
    * GtkCellAreaContext:natural-width:
    *
-   * The natural width for the #GtkCellArea in this context
-   * for all #GtkTreeModel rows that this context was requested
+   * The natural width for the `GtkCellArea` in this context
+   * for all `GtkTreeModel` rows that this context was requested
    * for using gtk_cell_area_get_preferred_width().
    */
   g_object_class_install_property (object_class,
                                    PROP_NAT_WIDTH,
-                                   g_param_spec_int ("natural-width",
-                                                     P_("Minimum Width"),
-                                                     P_("Minimum cached width"),
+                                   g_param_spec_int ("natural-width", NULL, NULL,
                                                      -1, G_MAXINT, -1,
                                                      GTK_PARAM_READABLE));
 
   /**
    * GtkCellAreaContext:minimum-height:
    *
-   * The minimum height for the #GtkCellArea in this context
-   * for all #GtkTreeModel rows that this context was requested
+   * The minimum height for the `GtkCellArea` in this context
+   * for all `GtkTreeModel` rows that this context was requested
    * for using gtk_cell_area_get_preferred_height().
    */
   g_object_class_install_property (object_class,
                                    PROP_MIN_HEIGHT,
-                                   g_param_spec_int ("minimum-height",
-                                                     P_("Minimum Height"),
-                                                     P_("Minimum cached height"),
+                                   g_param_spec_int ("minimum-height", NULL, NULL,
                                                      -1, G_MAXINT, -1,
                                                      GTK_PARAM_READABLE));
 
   /**
    * GtkCellAreaContext:natural-height:
    *
-   * The natural height for the #GtkCellArea in this context
-   * for all #GtkTreeModel rows that this context was requested
+   * The natural height for the `GtkCellArea` in this context
+   * for all `GtkTreeModel` rows that this context was requested
    * for using gtk_cell_area_get_preferred_height().
    */
   g_object_class_install_property (object_class,
                                    PROP_NAT_HEIGHT,
-                                   g_param_spec_int ("natural-height",
-                                                     P_("Minimum Height"),
-                                                     P_("Minimum cached height"),
+                                   g_param_spec_int ("natural-height", NULL, NULL,
                                                      -1, G_MAXINT, -1,
                                                      GTK_PARAM_READABLE));
 }
@@ -303,20 +293,20 @@ gtk_cell_area_context_real_allocate (GtkCellAreaContext *context,
  *************************************************************/
 /**
  * gtk_cell_area_context_get_area:
- * @context: a #GtkCellAreaContext
+ * @context: a `GtkCellAreaContext`
  *
- * Fetches the #GtkCellArea this @context was created by.
+ * Fetches the `GtkCellArea` this @context was created by.
  *
  * This is generally unneeded by layouting widgets; however,
  * it is important for the context implementation itself to
  * fetch information about the area it is being used for.
  *
- * For instance at #GtkCellAreaContextClass.allocate() time
+ * For instance at `GtkCellAreaContextClass.allocate()` time
  * it’s important to know details about any cell spacing
- * that the #GtkCellArea is configured with in order to
+ * that the `GtkCellArea` is configured with in order to
  * compute a proper allocation.
  *
- * Returns: (transfer none): the #GtkCellArea this context was created by.
+ * Returns: (transfer none): the `GtkCellArea` this context was created by.
  */
 GtkCellArea *
 gtk_cell_area_context_get_area (GtkCellAreaContext *context)
@@ -330,12 +320,12 @@ gtk_cell_area_context_get_area (GtkCellAreaContext *context)
 
 /**
  * gtk_cell_area_context_reset:
- * @context: a #GtkCellAreaContext
+ * @context: a `GtkCellAreaContext`
  *
  * Resets any previously cached request and allocation
  * data.
  *
- * When underlying #GtkTreeModel data changes its
+ * When underlying `GtkTreeModel` data changes its
  * important to reset the context if the content
  * size is allowed to shrink. If the content size
  * is only allowed to grow (this is usually an option
@@ -365,11 +355,11 @@ gtk_cell_area_context_reset (GtkCellAreaContext *context)
 
 /**
  * gtk_cell_area_context_allocate:
- * @context: a #GtkCellAreaContext
- * @width: the allocated width for all #GtkTreeModel rows rendered
- *     with @context, or -1.
- * @height: the allocated height for all #GtkTreeModel rows rendered
- *     with @context, or -1.
+ * @context: a `GtkCellAreaContext`
+ * @width: the allocated width for all `GtkTreeModel` rows rendered
+ *   with @context, or -1
+ * @height: the allocated height for all `GtkTreeModel` rows rendered
+ *   with @context, or -1
  *
  * Allocates a width and/or a height for all rows which are to be
  * rendered with @context.
@@ -379,8 +369,8 @@ gtk_cell_area_context_reset (GtkCellAreaContext *context)
  * side vertically or horizontally and share either the same width
  * or the same height. Sometimes they are allocated in both horizontal
  * and vertical orientations producing a homogeneous effect of the
- * rows. This is generally the case for #GtkTreeView when
- * #GtkTreeView:fixed-height-mode is enabled.
+ * rows. This is generally the case for `GtkTreeView` when
+ * `GtkTreeView:fixed-height-mode` is enabled.
  */
 void
 gtk_cell_area_context_allocate (GtkCellAreaContext *context,
@@ -394,17 +384,15 @@ gtk_cell_area_context_allocate (GtkCellAreaContext *context,
 
 /**
  * gtk_cell_area_context_get_preferred_width:
- * @context: a #GtkCellAreaContext
- * @minimum_width: (out) (allow-none): location to store the minimum width,
- *     or %NULL
- * @natural_width: (out) (allow-none): location to store the natural width,
- *     or %NULL
+ * @context: a `GtkCellAreaContext`
+ * @minimum_width: (out) (optional): location to store the minimum width
+ * @natural_width: (out) (optional): location to store the natural width
  *
  * Gets the accumulative preferred width for all rows which have been
  * requested with this context.
  *
  * After gtk_cell_area_context_reset() is called and/or before ever
- * requesting the size of a #GtkCellArea, the returned values are 0.
+ * requesting the size of a `GtkCellArea`, the returned values are 0.
  */
 void
 gtk_cell_area_context_get_preferred_width (GtkCellAreaContext *context,
@@ -424,17 +412,15 @@ gtk_cell_area_context_get_preferred_width (GtkCellAreaContext *context,
 
 /**
  * gtk_cell_area_context_get_preferred_height:
- * @context: a #GtkCellAreaContext
- * @minimum_height: (out) (allow-none): location to store the minimum height,
- *     or %NULL
- * @natural_height: (out) (allow-none): location to store the natural height,
- *     or %NULL
+ * @context: a `GtkCellAreaContext`
+ * @minimum_height: (out) (optional): location to store the minimum height
+ * @natural_height: (out) (optional): location to store the natural height
  *
  * Gets the accumulative preferred height for all rows which have been
  * requested with this context.
  *
  * After gtk_cell_area_context_reset() is called and/or before ever
- * requesting the size of a #GtkCellArea, the returned values are 0.
+ * requesting the size of a `GtkCellArea`, the returned values are 0.
  */
 void
 gtk_cell_area_context_get_preferred_height (GtkCellAreaContext *context,
@@ -454,18 +440,16 @@ gtk_cell_area_context_get_preferred_height (GtkCellAreaContext *context,
 
 /**
  * gtk_cell_area_context_get_preferred_height_for_width:
- * @context: a #GtkCellAreaContext
+ * @context: a `GtkCellAreaContext`
  * @width: a proposed width for allocation
- * @minimum_height: (out) (allow-none): location to store the minimum height,
- *     or %NULL
- * @natural_height: (out) (allow-none): location to store the natural height,
- *     or %NULL
+ * @minimum_height: (out) (optional): location to store the minimum height
+ * @natural_height: (out) (optional): location to store the natural height
  *
  * Gets the accumulative preferred height for @width for all rows
  * which have been requested for the same said @width with this context.
  *
  * After gtk_cell_area_context_reset() is called and/or before ever
- * requesting the size of a #GtkCellArea, the returned values are -1.
+ * requesting the size of a `GtkCellArea`, the returned values are -1.
  */
 void
 gtk_cell_area_context_get_preferred_height_for_width (GtkCellAreaContext *context,
@@ -484,18 +468,16 @@ gtk_cell_area_context_get_preferred_height_for_width (GtkCellAreaContext *contex
 
 /**
  * gtk_cell_area_context_get_preferred_width_for_height:
- * @context: a #GtkCellAreaContext
+ * @context: a `GtkCellAreaContext`
  * @height: a proposed height for allocation
- * @minimum_width: (out) (allow-none): location to store the minimum width,
- *     or %NULL
- * @natural_width: (out) (allow-none): location to store the natural width,
- *     or %NULL
+ * @minimum_width: (out) (optional): location to store the minimum width
+ * @natural_width: (out) (optional): location to store the natural width
  *
  * Gets the accumulative preferred width for @height for all rows which
  * have been requested for the same said @height with this context.
  *
  * After gtk_cell_area_context_reset() is called and/or before ever
- * requesting the size of a #GtkCellArea, the returned values are -1.
+ * requesting the size of a `GtkCellArea`, the returned values are -1.
  */
 void
 gtk_cell_area_context_get_preferred_width_for_height (GtkCellAreaContext *context,
@@ -514,9 +496,9 @@ gtk_cell_area_context_get_preferred_width_for_height (GtkCellAreaContext *contex
 
 /**
  * gtk_cell_area_context_get_allocation:
- * @context: a #GtkCellAreaContext
- * @width: (out) (allow-none): location to store the allocated width, or %NULL
- * @height: (out) (allow-none): location to store the allocated height, or %NULL
+ * @context: a `GtkCellAreaContext`
+ * @width: (out) (optional): location to store the allocated width
+ * @height: (out) (optional): location to store the allocated height
  *
  * Fetches the current allocation size for @context.
  *
@@ -542,15 +524,15 @@ gtk_cell_area_context_get_allocation (GtkCellAreaContext *context,
 
 /**
  * gtk_cell_area_context_push_preferred_width:
- * @context: a #GtkCellAreaContext
+ * @context: a `GtkCellAreaContext`
  * @minimum_width: the proposed new minimum width for @context
  * @natural_width: the proposed new natural width for @context
  *
  * Causes the minimum and/or natural width to grow if the new
  * proposed sizes exceed the current minimum and natural width.
  *
- * This is used by #GtkCellAreaContext implementations during
- * the request process over a series of #GtkTreeModel rows to
+ * This is used by `GtkCellAreaContext` implementations during
+ * the request process over a series of `GtkTreeModel` rows to
  * progressively push the requested width over a series of
  * gtk_cell_area_get_preferred_width() requests.
  */
@@ -584,15 +566,15 @@ gtk_cell_area_context_push_preferred_width (GtkCellAreaContext *context,
 
 /**
  * gtk_cell_area_context_push_preferred_height:
- * @context: a #GtkCellAreaContext
+ * @context: a `GtkCellAreaContext`
  * @minimum_height: the proposed new minimum height for @context
  * @natural_height: the proposed new natural height for @context
  *
  * Causes the minimum and/or natural height to grow if the new
  * proposed sizes exceed the current minimum and natural height.
  *
- * This is used by #GtkCellAreaContext implementations during
- * the request process over a series of #GtkTreeModel rows to
+ * This is used by `GtkCellAreaContext` implementations during
+ * the request process over a series of `GtkTreeModel` rows to
  * progressively push the requested height over a series of
  * gtk_cell_area_get_preferred_height() requests.
  */
