@@ -344,9 +344,7 @@ gtk_entry_buffer_class_init (GtkEntryBufferClass *klass)
    * The contents of the buffer.
    */
   entry_buffer_props[PROP_TEXT] =
-      g_param_spec_string ("text",
-                           P_("Text"),
-                           P_("The contents of the buffer"),
+      g_param_spec_string ("text", NULL, NULL,
                            "",
                            GTK_PARAM_READWRITE);
 
@@ -356,9 +354,7 @@ gtk_entry_buffer_class_init (GtkEntryBufferClass *klass)
    * The length (in characters) of the text in buffer.
    */
    entry_buffer_props[PROP_LENGTH] =
-       g_param_spec_uint ("length",
-                          P_("Text length"),
-                          P_("Length of the text currently in the buffer"),
+       g_param_spec_uint ("length", NULL, NULL,
                           0, GTK_ENTRY_BUFFER_MAX_SIZE, 0,
                           GTK_PARAM_READABLE);
 
@@ -368,9 +364,7 @@ gtk_entry_buffer_class_init (GtkEntryBufferClass *klass)
    * The maximum length (in characters) of the text in the buffer.
    */
   entry_buffer_props[PROP_MAX_LENGTH] =
-      g_param_spec_int ("max-length",
-                        P_("Maximum length"),
-                        P_("Maximum number of characters for this entry. Zero if no maximum"),
+      g_param_spec_int ("max-length", NULL, NULL,
                         0, GTK_ENTRY_BUFFER_MAX_SIZE, 0,
                         GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
 
@@ -378,7 +372,7 @@ gtk_entry_buffer_class_init (GtkEntryBufferClass *klass)
 
   /**
    * GtkEntryBuffer::inserted-text:
-   * @buffer: a #GtkEntryBuffer
+   * @buffer: a `GtkEntryBuffer`
    * @position: the position the text was inserted at.
    * @chars: The text that was inserted.
    * @n_chars: The number of characters that were inserted.
@@ -398,7 +392,7 @@ gtk_entry_buffer_class_init (GtkEntryBufferClass *klass)
 
   /**
    * GtkEntryBuffer::deleted-text:
-   * @buffer: a #GtkEntryBuffer
+   * @buffer: a `GtkEntryBuffer`
    * @position: the position the text was deleted at.
    * @n_chars: The number of characters that were deleted.
    *
@@ -424,7 +418,7 @@ gtk_entry_buffer_class_init (GtkEntryBufferClass *klass)
 
 /**
  * gtk_entry_buffer_new:
- * @initial_chars: (allow-none): initial buffer text, or %NULL
+ * @initial_chars: (nullable): initial buffer text
  * @n_initial_chars: number of characters in @initial_chars, or -1
  *
  * Create a new `GtkEntryBuffer` object.
@@ -466,7 +460,7 @@ gtk_entry_buffer_get_length (GtkEntryBuffer *buffer)
 
 /**
  * gtk_entry_buffer_get_bytes:
- * @buffer: a #GtkEntryBuffer
+ * @buffer: a `GtkEntryBuffer`
  *
  * Retrieves the length in bytes of the buffer.
  *
@@ -582,7 +576,7 @@ gtk_entry_buffer_set_max_length (GtkEntryBuffer *buffer,
  * Retrieves the maximum allowed length of the text in @buffer.
  *
  * Returns: the maximum allowed number of characters
- *   in #GtkEntryBuffer, or 0 if there is no maximum.
+ *   in `GtkEntryBuffer`, or 0 if there is no maximum.
  */
 int
 gtk_entry_buffer_get_max_length (GtkEntryBuffer *buffer)
