@@ -45,6 +45,7 @@
 #include "gtkprivate.h"
 #include "gtkwidgetprivate.h"
 #include "gtknative.h"
+#include "win32/gdkprivate-win32.h"
 
 #define MAX_PAGE_RANGES 20
 #define STATUS_POLLING_TIME 2000
@@ -539,7 +540,7 @@ win32_poll_status_timeout (GtkPrintOperation *op)
     op_win32->timeout_id = g_timeout_add (STATUS_POLLING_TIME,
 					  (GSourceFunc)win32_poll_status_timeout,
 					  op);
-    g_source_set_name_by_id (op_win32->timeout_id, "[gtk] win32_poll_status_timeout");
+    gdk_source_set_static_name_by_id (op_win32->timeout_id, "[gtk] win32_poll_status_timeout");
   }
   g_object_unref (op);
   return FALSE;
@@ -583,7 +584,7 @@ win32_end_run (GtkPrintOperation *op,
       op_win32->timeout_id = g_timeout_add (STATUS_POLLING_TIME,
 					    (GSourceFunc)win32_poll_status_timeout,
 					    op);
-      g_source_set_name_by_id (op_win32->timeout_id, "[gtk] win32_poll_status_timeout");
+      gdk_source_set_static_name_by_id (op_win32->timeout_id, "[gtk] win32_poll_status_timeout");
     }
   else
     /* Dunno what happened, pretend its finished */
