@@ -677,9 +677,7 @@ gtk_scale_class_init (GtkScaleClass *class)
    * The number of decimal places that are displayed in the value.
    */
   properties[PROP_DIGITS] =
-      g_param_spec_int ("digits",
-                        P_("Digits"),
-                        P_("The number of decimal places that are displayed in the value"),
+      g_param_spec_int ("digits", NULL, NULL,
                         -1, MAX_DIGITS,
                         1,
                         GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
@@ -690,9 +688,7 @@ gtk_scale_class_init (GtkScaleClass *class)
    * Whether the current value is displayed as a string next to the slider.
    */
   properties[PROP_DRAW_VALUE] =
-      g_param_spec_boolean ("draw-value",
-                            P_("Draw Value"),
-                            P_("Whether the current value is displayed as a string next to the slider"),
+      g_param_spec_boolean ("draw-value", NULL, NULL,
                             FALSE,
                             GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
 
@@ -702,9 +698,7 @@ gtk_scale_class_init (GtkScaleClass *class)
    * Whether the scale has an origin.
    */
   properties[PROP_HAS_ORIGIN] =
-      g_param_spec_boolean ("has-origin",
-                            P_("Has Origin"),
-                            P_("Whether the scale has an origin"),
+      g_param_spec_boolean ("has-origin", NULL, NULL,
                             TRUE,
                             GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
 
@@ -714,9 +708,7 @@ gtk_scale_class_init (GtkScaleClass *class)
    * The position in which the current value is displayed.
    */
   properties[PROP_VALUE_POS] =
-      g_param_spec_enum ("value-pos",
-                         P_("Value Position"),
-                         P_("The position in which the current value is displayed"),
+      g_param_spec_enum ("value-pos", NULL, NULL,
                          GTK_TYPE_POSITION_TYPE,
                          GTK_POS_TOP,
                          GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
@@ -964,7 +956,7 @@ gtk_scale_new (GtkOrientation  orientation,
  * @step is a power of ten. If the resulting precision is not suitable
  * for your needs, use [method@Gtk.Scale.set_digits] to correct it.
  *
- * Returns: a new #GtkScale
+ * Returns: a new `GtkScale`
  */
 GtkWidget *
 gtk_scale_new_with_range (GtkOrientation orientation,
@@ -1002,7 +994,7 @@ gtk_scale_new_with_range (GtkOrientation orientation,
  * gtk_scale_set_digits: (attributes org.gtk.Method.set_property=digits)
  * @scale: a `GtkScale`
  * @digits: the number of decimal places to display,
- *     e.g. use 1 to display 1.0, 2 to display 1.00, etc
+ *   e.g. use 1 to display 1.0, 2 to display 1.00, etc
  *
  * Sets the number of decimal places that are displayed in the value.
  *
@@ -1095,7 +1087,7 @@ update_value_position (GtkScale *scale)
 
 /**
  * gtk_scale_set_draw_value: (attributes org.gtk.Method.set_property=draw-value)
- * @scale: a #GtkScale
+ * @scale: a `GtkScale`
  * @draw_value: %TRUE to draw the value
  *
  * Specifies whether the current value is displayed as a string next
@@ -1595,9 +1587,9 @@ gtk_scale_get_layout (GtkScale *scale)
 
 /**
  * gtk_scale_get_layout_offsets:
- * @scale: a #GtkScale
- * @x: (out) (allow-none): location to store X offset of layout, or %NULL
- * @y: (out) (allow-none): location to store Y offset of layout, or %NULL
+ * @scale: a `GtkScale`
+ * @x: (out) (optional): location to store X offset of layout
+ * @y: (out) (optional): location to store Y offset of layout
  *
  * Obtains the coordinates where the scale will draw the
  * `PangoLayout` representing the text in the scale.
@@ -1674,12 +1666,11 @@ gtk_scale_clear_marks (GtkScale *scale)
  * @scale: a `GtkScale`
  * @value: the value at which the mark is placed, must be between
  *   the lower and upper limits of the scales’ adjustment
- * @position: where to draw the mark. For a horizontal scale, #GTK_POS_TOP
+ * @position: where to draw the mark. For a horizontal scale, %GTK_POS_TOP
  *   and %GTK_POS_LEFT are drawn above the scale, anything else below.
- *   For a vertical scale, #GTK_POS_LEFT and %GTK_POS_TOP are drawn to
+ *   For a vertical scale, %GTK_POS_LEFT and %GTK_POS_TOP are drawn to
  *   the left of the scale, anything else to the right.
- * @markup: (allow-none): Text to be shown at the mark, using
- *   Pango markup, or %NULL
+ * @markup: (nullable): Text to be shown at the mark, using Pango markup
  *
  * Adds a mark at @value.
  *
