@@ -68,7 +68,7 @@
  * are arranged in columns, and spread across several pages if there are too
  * many to find on a single page.
  *
- * The .ui file for this example can be found [here](https://gitlab.gnome.org/GNOME/gtk/tree/master/demos/gtk-demo/shortcuts-gedit.ui).
+ * The .ui file for this example can be found [here](https://gitlab.gnome.org/GNOME/gtk/tree/main/demos/gtk-demo/shortcuts-gedit.ui).
  *
  * # An example with multiple views:
  *
@@ -77,7 +77,7 @@
  * This example shows a `GtkShortcutsWindow` that has been configured to show only
  * the shortcuts relevant to the "stopwatch" view.
  *
- * The .ui file for this example can be found [here](https://gitlab.gnome.org/GNOME/gtk/tree/master/demos/gtk-demo/shortcuts-clocks.ui).
+ * The .ui file for this example can be found [here](https://gitlab.gnome.org/GNOME/gtk/tree/main/demos/gtk-demo/shortcuts-clocks.ui).
  *
  * # An example with multiple sections:
  *
@@ -86,7 +86,7 @@
  * This example shows a `GtkShortcutsWindow` with two sections, "Editor Shortcuts"
  * and "Terminal Shortcuts".
  *
- * The .ui file for this example can be found [here](https://gitlab.gnome.org/GNOME/gtk/tree/master/demos/gtk-demo/shortcuts-builder.ui).
+ * The .ui file for this example can be found [here](https://gitlab.gnome.org/GNOME/gtk/tree/main/demos/gtk-demo/shortcuts-builder.ui).
  */
 
 struct _GtkShortcutsWindow
@@ -749,7 +749,7 @@ gtk_shortcuts_window_class_init (GtkShortcutsWindowClass *klass)
    * objects that are in this shortcuts window.
    */
   properties[PROP_SECTION_NAME] =
-    g_param_spec_string ("section-name", P_("Section Name"), P_("Section Name"),
+    g_param_spec_string ("section-name", NULL, NULL,
                          "internal-search",
                          (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
@@ -765,7 +765,7 @@ gtk_shortcuts_window_class_init (GtkShortcutsWindowClass *klass)
    * Set this to %NULL to show all groups.
    */
   properties[PROP_VIEW_NAME] =
-    g_param_spec_string ("view-name", P_("View Name"), P_("View Name"),
+    g_param_spec_string ("view-name", NULL, NULL,
                          NULL,
                          (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
