@@ -47,7 +47,7 @@
  * etc. It supports autoplay, looping, and simple media controls. It does
  * not have support for video overlays, multichannel audio, device
  * selection, or input. If you are writing a full-fledged video player,
- * you may want to use the [class@Gdk.Paintable] API and a media framework
+ * you may want to use the [iface@Gdk.Paintable] API and a media framework
  * such as Gstreamer directly.
  */
 
@@ -314,9 +314,7 @@ gtk_video_class_init (GtkVideoClass *klass)
    * If the video should automatically begin playing.
    */
   properties[PROP_AUTOPLAY] =
-    g_param_spec_boolean ("autoplay",
-                          P_("Autoplay"),
-                          P_("If playback should begin automatically"),
+    g_param_spec_boolean ("autoplay", NULL, NULL,
                           FALSE,
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
@@ -326,9 +324,7 @@ gtk_video_class_init (GtkVideoClass *klass)
    * The file played by this video if the video is playing a file.
    */
   properties[PROP_FILE] =
-    g_param_spec_object ("file",
-                         P_("File"),
-                         P_("The video file played back"),
+    g_param_spec_object ("file", NULL, NULL,
                          G_TYPE_FILE,
                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
@@ -338,9 +334,7 @@ gtk_video_class_init (GtkVideoClass *klass)
    * If new media files should be set to loop.
    */
   properties[PROP_LOOP] =
-    g_param_spec_boolean ("loop",
-                          P_("Loop"),
-                          P_("If new media streams should be set to loop"),
+    g_param_spec_boolean ("loop", NULL, NULL,
                           FALSE,
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
@@ -350,9 +344,7 @@ gtk_video_class_init (GtkVideoClass *klass)
    * The media-stream played
    */
   properties[PROP_MEDIA_STREAM] =
-    g_param_spec_object ("media-stream",
-                         P_("Media Stream"),
-                         P_("The media stream played"),
+    g_param_spec_object ("media-stream", NULL, NULL,
                          GTK_TYPE_MEDIA_STREAM,
                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
@@ -661,7 +653,7 @@ gtk_video_set_media_stream (GtkVideo       *self,
 }
 
 /**
- * gtk_video_get_file: (attributes org.gtk.Method.get_propert=file)
+ * gtk_video_get_file: (attributes org.gtk.Method.get_property=file)
  * @self: a `GtkVideo`
  *
  * Gets the file played by @self or %NULL if not playing back
